==> v_chat_sdk-0.9.1.tar.gz: README.md <==
# V_Chat_SDK Micro service

## Check Our Full documention 
<a href="https://hatemragab.github.io/VChatSdk-Documentation/"> VCHAT Documention</a>  <br />
<a href="https://pub.dev/packages/v_chat_sdk"> v_chat_sdk on pub.dev</a>  <br />


## Android Test

<a href="https://drive.google.com/file/d/1BpEY2wrzzPqbgT-la0-xHc6VbwFVJ5rz/view?usp=sharing"> <img src="https://user-images.githubusercontent.com/37384769/145644981-17ec8f75-be19-4cea-9322-52f1b31a15da.png" width ="300" /></a> <br />

## IOS Test Flight

<a href="https://testflight.apple.com/join/Bb2LLcKx"> <img src="https://user-images.githubusercontent.com/37384769/145644883-e914dd94-c797-4944-bb6d-fb4ec629c016.png" width ="300" /> </a> <br />



**Quick Review**
![carbon](https://user-images.githubusercontent.com/37384769/137525753-03155709-c903-4b4d-89bf-ee40e0525d63.png)

### Android <br />

<p float="left">
  <img src="https://user-images.githubusercontent.com/37384769/138588123-8919321f-132e-4913-9e81-6c0d6a915d8f.jpeg"   width ="200" /> 
  <img src="https://user-images.githubusercontent.com/37384769/138588161-836214c0-0d54-480a-8030-3679430656b5.jpeg"   width ="200" />
   <img src="https://user-images.githubusercontent.com/37384769/138588227-31de6adc-fb1e-49b5-baa0-5fe554d3e841.jpeg" width ="200"  /> 
  <img src="https://user-images.githubusercontent.com/37384769/138588252-5e7cfd5c-3955-48ca-b8d2-78352abb9d87.jpeg"   width ="200" />
</p>

 

### IOS <br />
<p float="left">
  <img src="https://user-images.githubusercontent.com/37384769/145550341-b155ce1b-ab0d-4cbe-b82f-cddf89e37638.PNG"   width ="200" /> 
  <img src="https://user-images.githubusercontent.com/37384769/145550352-e3185015-073e-4980-b3a3-37c669ca444e.PNG"   width ="200" />
  
   
  <img src="https://user-images.githubusercontent.com/37384769/145550367-52eda5d9-9d8f-4bc8-89a7-4373e1ab2d7f.PNG"   width ="200" /> 
  <img src="https://user-images.githubusercontent.com/37384769/145550323-73d75d9a-dabf-4301-be56-072c2603f359.PNG"   width ="200" /> 
</p>



Don't forget to see the example attached to github here <a href="https://github.com/hatemragab/v_chat_sdk/tree/master/example">V_CHAT_SDK Example</a>  <br />



---
# Featurs
<table>
  <tr>
    <th>Name</th>
    <th>Android</th>
    <th>Ios</th>
  </tr>

  <tr>
    <td>online/offline</td>
    <td>👍</td>
    <td>👍</td>
  </tr>

  <tr>
    <td>textMessage/typing...</td>
    <td>👍</td>
    <td>👍</td>
  </tr>


  <tr>
    <td>voiceRecord/recording...</td>
    <td>👍</td>
    <td>👍</td>
  </tr>


  <tr>
    <td>saned video/file/images</td>
    <td>👍</td>
    <td>👍</td>
  </tr>

  <tr>
    <td>cache all media</td>
    <td>👍</td>
    <td>👍</td>
  </tr>

  <tr>
    <td>message notification</td>
    <td>👍</td>
    <td>👍</td>
  </tr>


  <tr>
    <td>mute/un mute notification</td>
    <td>👍</td>
    <td>👍</td>
  </tr>

 <tr>
    <td>block/un block users</td>
    <td>👍</td>
    <td>👍</td>
  </tr>

 <tr>
    <td>message status/read/unread</td>
    <td>👍</td>
    <td>👍</td>
  </tr>

 <tr>
    <td>smooth performance</td>
    <td>👍</td>
    <td>👍</td>
 </tr>
    <tr>
    <td>Group Chat v1 added</td>
    <td>👍</td>
    <td>👍</td>
  </tr>
</table>


## Check Our Full documention 
<a href="https://hatemragab.github.io/VChatSdk-Documentation/"> VCHAT DOCS</a>  <br />

==> v_chat_sdk-1.0.1.tar.gz: README.md <==
# V_Chat_SDK Micro service

## Check Our Full documention 
<a href="https://hatemragab.github.io/VChatSdk-Documentation/"> VCHAT Documention</a>  <br />
<a href="https://pub.dev/packages/v_chat_sdk"> v_chat_sdk on pub.dev</a>  <br />


## Android Test

<a href="https://drive.google.com/file/d/1BpEY2wrzzPqbgT-la0-xHc6VbwFVJ5rz/view?usp=sharing"> <img src="https://user-images.githubusercontent.com/37384769/145644981-17ec8f75-be19-4cea-9322-52f1b31a15da.png" width ="300" /></a> <br />

## IOS Test Flight

<a href="https://testflight.apple.com/join/Bb2LLcKx"> <img src="https://user-images.githubusercontent.com/37384769/145644883-e914dd94-c797-4944-bb6d-fb4ec629c016.png" width ="300" /> </a> <br />



**Quick Review**
![carbon](https://user-images.githubusercontent.com/37384769/137525753-03155709-c903-4b4d-89bf-ee40e0525d63.png)

### Android <br />

<p float="left">
  <img src="https://user-images.githubusercontent.com/37384769/138588123-8919321f-132e-4913-9e81-6c0d6a915d8f.jpeg"   width ="200" /> 
  <img src="https://user-images.githubusercontent.com/37384769/138588161-836214c0-0d54-480a-8030-3679430656b5.jpeg"   width ="200" />
   <img src="https://user-images.githubusercontent.com/37384769/138588227-31de6adc-fb1e-49b5-baa0-5fe554d3e841.jpeg" width ="200"  /> 
  <img src="https://user-images.githubusercontent.com/37384769/138588252-5e7cfd5c-3955-48ca-b8d2-78352abb9d87.jpeg"   width ="200" />
</p>

 

### IOS <br />
<p float="left">
  <img src="https://user-images.githubusercontent.com/37384769/145550341-b155ce1b-ab0d-4cbe-b82f-cddf89e37638.PNG"   width ="200" /> 
  <img src="https://user-images.githubusercontent.com/37384769/145550352-e3185015-073e-4980-b3a3-37c669ca444e.PNG"   width ="200" />
  
   
  <img src="https://user-images.githubusercontent.com/37384769/145550367-52eda5d9-9d8f-4bc8-89a7-4373e1ab2d7f.PNG"   width ="200" /> 
  <img src="https://user-images.githubusercontent.com/37384769/145550323-73d75d9a-dabf-4301-be56-072c2603f359.PNG"   width ="200" /> 
</p>



Don't forget to see the example attached to github here <a href="https://github.com/hatemragab/v_chat_sdk/tree/master/example">V_CHAT_SDK Example</a>  <br />



---
# Featurs
<table>
  <tr>
    <th>Name</th>
    <th>Android</th>
    <th>Ios</th>
  </tr>

  <tr>
    <td>online/offline</td>
    <td>👍</td>
    <td>👍</td>
  </tr>

  <tr>
    <td>textMessage/typing...</td>
    <td>👍</td>
    <td>👍</td>
  </tr>


  <tr>
    <td>voiceRecord/recording...</td>
    <td>👍</td>
    <td>👍</td>
  </tr>


  <tr>
    <td>saned video/file/images</td>
    <td>👍</td>
    <td>👍</td>
  </tr>

  <tr>
    <td>cache all media</td>
    <td>👍</td>
    <td>👍</td>
  </tr>

  <tr>
    <td>message notification</td>
    <td>👍</td>
    <td>👍</td>
  </tr>


  <tr>
    <td>mute/un mute notification</td>
    <td>👍</td>
    <td>👍</td>
  </tr>

 <tr>
    <td>block/un block users</td>
    <td>👍</td>
    <td>👍</td>
  </tr>

 <tr>
    <td>message status/read/unread</td>
    <td>👍</td>
    <td>👍</td>
  </tr>
 </tr>
    <tr>
    <td>un read message count</td>
    <td>👍</td>
    <td>👍</td>
  </tr>
 <tr>
    <td>smooth performance</td>
    <td>👍</td>
    <td>👍</td>

 </tr>
    <tr>
    <td>Group Chat with administration system</td>
    <td>👍</td>
    <td>👍</td>
  </tr>
</table>


## Check Our Full documention 
<a href="https://hatemragab.github.io/VChatSdk-Documentation/"> VCHAT DOCS</a>  <br />
